@@ -7,8 +7,16 @@ def load(stream):
     return yaml.load(stream, Loader=yaml.SafeLoader)
 
 
+def load_all(stream):
+    return yaml.load_all(stream, Loader=yaml.SafeLoader)
+
+
 def dump(content, fileobj):
-    yaml.dump(content, fileobj, default_flow_style=False)
+    yaml.dump(content, stream=fileobj, default_flow_style=False)
+
+
+def dumps(content):
+    return yaml.dump(content, stream=None, default_flow_style=False)
 
 
 def parse(v):
